==> nextcloud-app-tasks-0.13.1-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/tasks/l10n/eu.js <==
OC.L10N.register(
    "tasks",
    {
    "Important" : "Garrantzitsua",
    "Today" : "Gaur",
    "Week" : "Astea",
    "All" : "Denak",
    "Current" : "Unekoa",
    "Completed" : "Osatua",
    "Tasks" : "Atazak",
    "The Tasks app for Nextcloud" : "Nextcloudeko Atazak aplikazioa",
    "Share with users or groups" : "Partekatu erabiltzaile edo taldeekin",
    "No users or groups" : "Ez dago erabiltzaile edo talderik",
    "can edit" : "edita daiteke",
    "Unshare with {displayName}" : "Utzi {displayName} erabiltzailearekin partekatzeari",
    "Unable to delete the share." : "Ezin da partekatzea ezabatu.",
    "Unable to change permissions." : "Ezin dira baimenak aldatu.",
    "Add List…" : "Gehitu zerrenda...",
    "New List" : "Zerrenda berria",
    "Cancel" : "Ezeztatu",
    "Save" : "Gorde",
    "The name \"{calendar}\" is already used." : "\"{calendar}\" izena badago dagoeneko.",
    "An empty name is not allowed." : "Ez da izen hutsik onartzen.",
    "Edit" : "Editatu",
    "Copy private link" : "Kopiatu esteka pribatua",
    "Copied" : "Kopiatuta",
    "Can not copy" : "Ezin da kopiatu",
    "Download" : "Deskargatu",
    "Delete" : "Ezabatu",
    "Unshare" : "Ez partekatu",
    "This will delete the calendar \"{calendar}\" and all corresponding events and tasks." : "Honek \"{calendar}\" egutegia eta bere gertaera eta ataza guztiak ezabatuko ditu.",
    "Calendar link copied to clipboard." : "Egutegiko esteka arbelera kopiatu da.",
    "Calendar link could not be copied to clipboard." : "Ezin izan da egutegiko esteka arbelera kopiatu.",
    "An error occurred, unable to delete the calendar." : "Errore bat gertatu da, ezin da egutegia ezabatu.",
    "_Shared with {num} entity_::_Shared with {num} entities_" : ["Entitate {num}ekin partekatua","{num} entitaterekin partekatua"],
    "Default list" : "Zerrenda lehenetsia",
    "Visibility of Smart Collections" : "Bilduma adimendunen ikusgaitasuna",
    "Hidden" : "Ezkutuan",
    "Visible" : "Ikusgai",
    "Automatic" : "Automatikoa",
    "Delete all completed tasks." : "Ezabatu osatutako ataza guztiak.",
    "Delete completed tasks." : "Ezabatu osatutako atazak.",
    "Deleted all completed tasks from calendar \"{calendar}\"." : "\"{calendar}\" egutegiko osatutako ataza guztiak ezabatu dira.",
    "No errors" : "Errorerik ez",
    "Open your browser console for more details" : "Ireki nabigatzailearen kontsola xehetasun gehiagorako",
    "_This will delete {taskCount} completed task and its subtasks from calendar \"{calendar}\"._::_This will delete {taskCount} completed tasks and their subtasks from calendar \"{calendar}\"._" : ["Honek osatutako ataza {taskCount} eta beren azpi-atazak ezabatuko ditu \"{calendar}\" egutegitik.","Honek osatutako {taskCount} ataza eta beren azpi-atazak ezabatuko ditu \"{calendar}\" egutegitik."],
    "_Could not delete {failedCount} task._::_Could not delete {failedCount} tasks._" : ["Ezin izan da ataza {failedCount} ezabatu.","Ezin izan dira {failedCount} ataza ezabatu."],
    "Load all completed tasks." : "Kargatu osatutako ataza guztiak.",
    "Change sort order" : "Aldatu ordenatzeko irizpidea",
    "Sort by completed state, due date, priority, start date and summary." : "Ordenatu osatutako egoera, epemuga, lehentasuna, hasiera-data eta laburpenaren arabera.",
    "Start date" : "Hasiera-data",
    "Sort by start date and summary." : "Ordenatu hasiera-data eta laburpenaren arabera.",
    "Due date" : "Epemuga",
    "Sort by due date and summary." : "Ordenatu epemuga eta laburpenaren arabera.",
    "Created date" : "Sortze-data",
    "Sort by created date and summary." : "Ordenatu sortze-data eta laburpenaren arabera",
    "Last modified" : "Azken aldaketa",
    "Sort by last-modified date and summary." : "Ordenatu azken aldaketaren data eta laburpenaren arabera.",
    "Completed date" : "Osatze-data",
    "Sort by completed date." : "Ordenatu osatze-dataren arabera",
    "Priority" : "Lehentasuna",
    "Sort by priority and summary." : "Ordenatu lehentasuna eta laburpenaren arabera.",
    "Alphabetically" : "Alfabetikoki",
    "Sort by summary and priority." : "Ordenatu laburpena eta lehentasunaren arabera.",
    "Manually" : "Eskuz",
    "Sort by manual order." : "Ordenatu eskuz.",
    "Task is completed" : "Ataza osatuta",
    "{complete} % completed" : "% {complete} osatuta",
    "[Yesterday]" : "[Atzo]",
    "[Today]" : "[Gaur]",
    "[Tomorrow]" : "[Bihar]",
    "Add a subtask to \"{task}\"…" : "Gehitu azpi-ataza bat \"{task}\" atazari…",
    "Add a task to \"{task}\"…" : "Gehitu ataza bat \"{task}\" atazari…",
    "_%n Completed Task_::_%n Completed Tasks_" : ["Ataza %n osatuta","%n ataza osatuta"],
    "Add an important task to \"{calendar}\"…" : "Gehitu ataza garrantzitsu bat \"{calendar}\" egutegiari…",
    "Add a task due today to \"{calendar}\"…" : "Gehitu gaurko epemuga bat duen ataza bat \"{calendar}\" egutegiari…",
    "Add a current task to \"{calendar}\"…" : "Gehitu uneko ataza bat \"{calendar}\" egutegiari…",
    "Add a task to \"{calendar}\"…" : "Gehitu ataza bat \"{calendar}\" egutegiari…",
    "Tomorrow" : "Bihar",
    "Set start date" : "Ezarri hasiera-data",
    "Set start time" : "Ezarri hasiera-ordua",
    "Set due date" : "Ezarri epemuga",
    "Set due time" : "Ezarri epemugako ordua",
    "All day" : "Egun osoa",
    "Select a calendar" : "Hautatu egutegi bat",
    "Select a classification" : "Hautatu sailkapen bat",
    "Select a status" : "Hautatu egoera bat",
    "Select categories" : "Hautatu kategoriak",
    "Add this as a new category" : "Gehitu hau kategoria berri bezala",
    "Loading task from server." : "Ataza zerbitzaritik kargatzen.",
    "Task not found!" : "Ez da ataza aurkitu!",
    "When shared show full event" : "Partekatzean erakutsi gertaera osoa",
    "When shared show only busy" : "Partekatzean okupatua bezala erakutsi soilik",
    "When shared hide this event" : "Partekatzean ezkutatu gertaera hau",
    "Needs action" : "Ekintza behar du",
    "In process" : "Abian",
    "Canceled" : "Utzita",
    "[Starts today]" : "[Gaur hasten da]",
    "[Starts tomorrow]" : "[Bihar hasten da]",
    "[Started yesterday]" : "[Atzo hasi zen]",
    "[Due today]" : "[Epemuga gaur]",
    "[Due tomorrow]" : "[Epemuga bihar]",
    "[Was due yesterday]" : "[Epemuga atzo]",
    "Last modified {date}" : "Azken aldaketa {date}",
    "Created {date}" : "Sortze-data {date}",
    "Completed {date}" : "Osatze-data {date}",
    "No priority assigned" : "Lehentasuna ezarri gabe",
    "Priority {priority}: high" : "Lehentasuna {priority}: altua",
    "Priority {priority}: medium" : "Lehentasuna {priority}: ertaina",
    "Priority {priority}: low" : "Lehentasuna {priority}: baxua",
    "{percent} % completed" : "% {percent} osatuta",
    "Could not delete the task." : "Ezin izan da ataza ezabatu.",
    "Synchronizing to the server." : "Zerbitzariarekin sinkronizatzen.",
    "Task successfully saved to server." : "Ataza behar bezala gorde da zerbitzarian.",
    "Could not update the task because it was changed on the server. Please click to refresh it, local changes will be discarded." : "Ezin izan da ataza eguneratu, zerbitzarian aldatua zegoelako. Egin klik freskatzeko, aldaketa lokalak baztertuko dira.",
    "Could not update the task." : "Ezin izan da ataza eguneratu.",
    "An error occurred" : "Errore bat gertatu da"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-app-tasks-0.13.2-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/tasks/l10n/eu.js <==
OC.L10N.register(
    "tasks",
    {
    "Important" : "Garrantzitsua",
    "Today" : "Gaur",
    "Week" : "Astea",
    "All" : "Denak",
    "Current" : "Unekoa",
    "Completed" : "Osatua",
    "Tasks" : "Atazak",
    "The Tasks app for Nextcloud" : "Nextcloudeko Atazak aplikazioa",
    "Add List…" : "Gehitu zerrenda...",
    "New List" : "Zerrenda berria",
    "Cancel" : "Ezeztatu",
    "Save" : "Gorde",
    "The name \"{calendar}\" is already used." : "\"{calendar}\" izena badago dagoeneko.",
    "An empty name is not allowed." : "Ez da izen hutsik onartzen.",
    "Share with users or groups" : "Partekatu erabiltzaile edo taldeekin",
    "No users or groups" : "Ez dago erabiltzaile edo talderik",
    "can edit" : "edita daiteke",
    "Unshare with {displayName}" : "Utzi {displayName} erabiltzailearekin partekatzeari",
    "Unable to delete the share." : "Ezin da partekatzea ezabatu.",
    "Unable to change permissions." : "Ezin dira baimenak aldatu.",
    "Edit" : "Editatu",
    "Copy private link" : "Kopiatu esteka pribatua",
    "Copied" : "Kopiatuta",
    "Can not copy" : "Ezin da kopiatu",
    "Download" : "Deskargatu",
    "Delete" : "Ezabatu",
    "Unshare" : "Ez partekatu",
    "This will delete the calendar \"{calendar}\" and all corresponding events and tasks." : "Honek \"{calendar}\" egutegia eta bere gertaera eta ataza guztiak ezabatuko ditu.",
    "Calendar link copied to clipboard." : "Egutegiko esteka arbelera kopiatu da.",
    "Calendar link could not be copied to clipboard." : "Ezin izan da egutegiko esteka arbelera kopiatu.",
    "An error occurred, unable to delete the calendar." : "Errore bat gertatu da, ezin da egutegia ezabatu.",
    "_Deleting the calendar in {countdown} second_::_Deleting the calendar in {countdown} seconds_" : ["Egutegia ezabatzen segundu {countdown}ean","Egutegia ezabatzen {countdown} segundutan"],
    "_Shared with {num} entity_::_Shared with {num} entities_" : ["Entitate {num}ekin partekatua","{num} entitaterekin partekatua"],
    "Default list" : "Zerrenda lehenetsia",
    "Visibility of Smart Collections" : "Bilduma adimendunen ikusgaitasuna",
    "Hidden" : "Ezkutuan",
    "Visible" : "Ikusgai",
    "Automatic" : "Automatikoa",
    "Delete all completed tasks." : "Ezabatu osatutako ataza guztiak.",
    "Delete completed tasks." : "Ezabatu osatutako atazak.",
    "Deleted all completed tasks from calendar \"{calendar}\"." : "\"{calendar}\" egutegiko osatutako ataza guztiak ezabatu dira.",
    "No errors" : "Errorerik ez",
    "Open your browser console for more details" : "Ireki nabigatzailearen kontsola xehetasun gehiagorako",
    "_This will delete {taskCount} completed task and its subtasks from calendar \"{calendar}\"._::_This will delete {taskCount} completed tasks and their subtasks from calendar \"{calendar}\"._" : ["Honek osatutako ataza {taskCount} eta beren azpi-atazak ezabatuko ditu \"{calendar}\" egutegitik.","Honek osatutako {taskCount} ataza eta beren azpi-atazak ezabatuko ditu \"{calendar}\" egutegitik."],
    "_Could not delete {failedCount} task._::_Could not delete {failedCount} tasks._" : ["Ezin izan da ataza {failedCount} ezabatu.","Ezin izan dira {failedCount} ataza ezabatu."],
    "Load all completed tasks." : "Kargatu osatutako ataza guztiak.",
    "Change sort order" : "Aldatu ordenatzeko irizpidea",
    "Sort by completed state, due date, priority, start date and summary." : "Ordenatu osatutako egoera, epemuga, lehentasuna, hasiera-data eta laburpenaren arabera.",
    "Start date" : "Hasiera-data",
    "Sort by start date and summary." : "Ordenatu hasiera-data eta laburpenaren arabera.",
    "Due date" : "Epemuga",
    "Sort by due date and summary." : "Ordenatu epemuga eta laburpenaren arabera.",
    "Created date" : "Sortze-data",
    "Sort by created date and summary." : "Ordenatu sortze-data eta laburpenaren arabera",
    "Last modified" : "Azken aldaketa",
    "Sort by last-modified date and summary." : "Ordenatu azken aldaketaren data eta laburpenaren arabera.",
    "Completed date" : "Osatze-data",
    "Sort by completed date." : "Ordenatu osatze-dataren arabera",
    "Priority" : "Lehentasuna",
    "Sort by priority and summary." : "Ordenatu lehentasuna eta laburpenaren arabera.",
    "Alphabetically" : "Alfabetikoki",
    "Sort by summary and priority." : "Ordenatu laburpena eta lehentasunaren arabera.",
    "Manually" : "Eskuz",
    "Sort by manual order." : "Ordenatu eskuz.",
    "Task is completed" : "Ataza osatuta",
    "{complete} % completed" : "% {complete} osatuta",
    "Add subtask" : "Gehitu azpizeregina",
    "Show subtasks" : "Erakutsi azpizereginak",
    "Hide subtasks" : "Ezkutatu azpizereginak",
    "Show completed subtasks" : "Erakutsi bukatutako zereginak",
    "Hide completed subtasks" : "Ezkutatu bukatutako azpizereginak",
    "Delete task" : "Ezabatu zeregina",
    "[Yesterday]" : "[Atzo]",
    "[Today]" : "[Gaur]",
    "[Tomorrow]" : "[Bihar]",
    "Add a subtask to \"{task}\"…" : "Gehitu azpi-ataza bat \"{task}\" atazari…",
    "Add a task to \"{task}\"…" : "Gehitu ataza bat \"{task}\" atazari…",
    "_%n Completed Task_::_%n Completed Tasks_" : ["Ataza %n osatuta","%n ataza osatuta"],
    "Add an important task to \"{calendar}\"…" : "Gehitu ataza garrantzitsu bat \"{calendar}\" egutegiari…",
    "Add a task due today to \"{calendar}\"…" : "Gehitu gaurko epemuga bat duen ataza bat \"{calendar}\" egutegiari…",
    "Add a current task to \"{calendar}\"…" : "Gehitu uneko ataza bat \"{calendar}\" egutegiari…",
    "Add a task to \"{calendar}\"…" : "Gehitu ataza bat \"{calendar}\" egutegiari…",
    "Tomorrow" : "Bihar",
    "Set start date" : "Ezarri hasiera-data",
    "Set start time" : "Ezarri hasiera-ordua",
    "Set due date" : "Ezarri epemuga",
    "Set due time" : "Ezarri epemugako ordua",
    "All day" : "Egun osoa",
    "Select a calendar" : "Hautatu egutegi bat",
    "Select a classification" : "Hautatu sailkapen bat",
    "Select a status" : "Hautatu egoera bat",
    "Select categories" : "Hautatu kategoriak",
    "Add this as a new category" : "Gehitu hau kategoria berri bezala",
    "Loading task from server." : "Ataza zerbitzaritik kargatzen.",
    "Task not found!" : "Ez da ataza aurkitu!",
    "When shared show full event" : "Partekatzean erakutsi gertaera osoa",
    "When shared show only busy" : "Partekatzean okupatua bezala erakutsi soilik",
    "When shared hide this event" : "Partekatzean ezkutatu gertaera hau",
    "Needs action" : "Ekintza behar du",
    "In process" : "Abian",
    "Canceled" : "Utzita",
    "[Starts today]" : "[Gaur hasten da]",
    "[Starts tomorrow]" : "[Bihar hasten da]",
    "[Started yesterday]" : "[Atzo hasi zen]",
    "[Due today]" : "[Epemuga gaur]",
    "[Due tomorrow]" : "[Epemuga bihar]",
    "[Was due yesterday]" : "[Epemuga atzo]",
    "Last modified {date}" : "Azken aldaketa {date}",
    "Created {date}" : "Sortze-data {date}",
    "Completed {date}" : "Osatze-data {date}",
    "No priority assigned" : "Lehentasuna ezarri gabe",
    "Priority {priority}: high" : "Lehentasuna {priority}: altua",
    "Priority {priority}: medium" : "Lehentasuna {priority}: ertaina",
    "Priority {priority}: low" : "Lehentasuna {priority}: baxua",
    "{percent} % completed" : "% {percent} osatuta",
    "Could not delete the task." : "Ezin izan da ataza ezabatu.",
    "Synchronizing to the server." : "Zerbitzariarekin sinkronizatzen.",
    "Task successfully saved to server." : "Ataza behar bezala gorde da zerbitzarian.",
    "Could not update the task because it was changed on the server. Please click to refresh it, local changes will be discarded." : "Ezin izan da ataza eguneratu, zerbitzarian aldatua zegoelako. Egin klik freskatzeko, aldaketa lokalak baztertuko dira.",
    "Could not update the task." : "Ezin izan da ataza eguneratu.",
    "An error occurred" : "Errore bat gertatu da"
},
"nplurals=2; plural=(n != 1);");
